﻿import com.delfiweb.forms.*
/**
 *	A l'instar de la classe Form, la classe FormComponent a le même rôle,
 * 	elle joue le rôle de classe abstraite. En gros elle fournit 2 ou 3
 * 	fonctionnalité de base comme la possibilité d'avoir une fonction de
 * 	vérification de la saisie.
 * 
 *	@author		Cedric Néhémie
 *	@version	0.1
 *	@see		MovieClip	
 *	@see		IFormComponent	
 *	@class		FormComponent
 */
class com.delfiweb.forms.FormComponent extends MovieClip implements IFormComponent 
{
	private var value;						// valeur du formulaire (a typer dans les classes filles)		
	
	public var onChange:Function;			// handler de changement de valeur
	public var verifyMethod:Function;		// fonction de vérification custom
	
	
	/**
	 *	Super Constructeur de la classe, on peut s'en servir
	 * 	pour déterminer le type de vérification la classe fille devra
	 * 	réaliser sur la valeur interne.
	 * 
	 * 	@method	FormComponent
	 * 	entrée :	f	Function Fonction de vérification
	 *	utilisation :	super(func);
	 *	sortie :	Void
	 */
	private function FormComponent (f:Function)
	{
		verifyMethod = f;
	}
	
	
	/**
	 *	Appel la fonction de vérification définie par la classe Fille.
	 * 	Elle renvoie le résultat de cette dernière.
	 * 
	 * 	@method	verifyInput
	 *	utilisation :	if(verifyInput()) { ... }
	 *	sortie :	Boolean	La valeur est-elle valide ?
	 */
	public function verifyInput ():Boolean
	{ 
		return verifyMethod(value);
	}
	
	
	/**
	 *	Permet de vérifier la comformité d'un entier, ou d'une
	 * 	valeur sensé être entière, ce qui signifie que si elle
	 * 	ne l'est pas la valeur devra être modifié manuellement.
	 * 	Si la valeur était un float on l'arrondi au nombre inférieure.
	 * 
	 * 	@method	verifyInt
	 * 	entrée :	v	Number
	 *	utilisation :	verifyInt(value);
	 *	sortie :	Boolean
	 */
	private function verifyInt (v:Number):Boolean
	{
		// si la valeur n'est pas définie ou que ce n'est pas un nombre.
		if(v == undefined || isNaN(v))
		{
			return false;
		}	
		// si c'est un float on fait un arrondi
		else if(v.toString().indexOf(".") != -1)
		{
			value = Math.floor(v);
			return true;
		}
		// autrement c'est bon
		else
		{
			return true;
		}
	}
	
	
	/**
	 *	Permet de vérifier la comformité d'un float, ou d'une
	 * 	valeur sensé l'être, ce qui signifie que si elle
	 * 	ne l'est pas la valeur devra être modifié manuellement.
	 * 
	 * 	@method	verifyFloat
	 * 	entrée :	v	Number
	 *	utilisation :	verifyFloat(value);
	 *	sortie :	Boolean
	 */
	private function verifyFloat (v:Number):Boolean
	{
		// si la valeur n'est pas définie ou que ce n'est pas un nombre.
		if(v == undefined || isNaN(v))
		{
			return false;
		}
		// autrement c'est bon
		else
		{
			return true;
		}
	}
	
	
	/**
	 *	Permet de vérifier la comformité d'une chaine, par contre
	 * 	elle ne vérifie pas par exemple si c'est bien un mail, en 
	 * 	plus avec l'absence de module de RegExp on ne peut pas non
	 * 	plus hyper sécurisé le texte.
	 * 
	 * 	@method	verifyString
	 * 	entrée :	v	String
	 *	utilisation :	verifyString(value);
	 *	sortie :	Boolean
	 */
	private function verifyString (v:String):Boolean
	{
		// si la valeur n'est pas définie ou que ce n'est pas une chaine.
		if(v == undefined || typeof v != "string")
		{
			return false;
		}
		// autrement c'est bon
		else
		{
			return true;
		}
	}
	
	
	
	/**
	 *	Permet de vérifier la présence ou non de ce qui en général 
	 * 	caractérise un mail, c'est-à-dire la présence d'un @ et d'un
	 * 	nom de domaine.
	 * 
	 * 	@method	verifyMail
	 * 	entrée :	v	String
	 *	utilisation :	verifyMail(value);
	 *	sortie :	Boolean
	 */
	private function verifyMail (v:String):Boolean
	{
		// si la valeur n'est pas définie ou que ce n'est pas une chaine.
		if(v == undefined || typeof v != "string")
		{
			return false;
		}
		else
		{
			// si on a bien un caractere @ et qu'il n'est pas placé au début
			if(v.indexOf("@") == -1 || v.indexOf("@") == v.length-1 || v.indexOf("@") == 0) 
			{
				return false;
			}
			else
			{
				
				var a = v.split("@")
				// ensuite on vérifie si il y a une extension et un préfixe
				if(a[1].indexOf(".") == -1 || a[1].indexOf(".") == a[1].length-1 || a[0].length != 0)
				{
					return false;
				}
				else
				{
					return true;
				}
			}
		}
	}
	
}