﻿import com.delfiweb.forms.*

/**
 *	Classe d'erreur de formulaire, si par exemple un champs n'est
 *  pas rempli lors d'une étape, ou que sa valeur n'est pas valide
 * 	on créer une <i>FormError</i>. Le paramètre message sert a l'affichage
 *  de l'erreur, le <i>behaviour</i> lui sert a gérér les comportements en
 * 	cas d'erreur, certaines peuvent être bloquantes d'autre pas...
 * 
 *	@author		Cedric Néhémie
 *	@version	0.1
 *	@see		Error	
 *	@class		FormError
 */
class com.delfiweb.forms.FormError extends Error 
{
	private var message:String		// message de l'erreur
	private var behaviour:Function	// comportement de l'erreur, 
									// que fait t'on une fois l'erreur générer
	
	/**
	 *	Créer une erreur de formulaire avec la possibilité d'avoir une action
	 * 	de réponse à l'erreur (<i>behaviour</i>).
	 * 
	 * 	@method	FormError
	 * 	entrée :	m	String		Message d'erreur
	 * 	entrée :	b	Function	Fonction de callback
	 *	utilisation :	throw new FormError ("une erreur");
	 * 	utilisation :	throw new FormError ("une erreur", Delegate.create(_root, _root.behaviour));
	 *	sortie :	Void
	 */
	public function FormError (m:String, b:Function)
	{
		behaviour = b;
		message = m;
	}
	
	
	/**
	 *	Lance l'appel du comportement de l'erreur, si celle-ci en possède 1.
	 * 	Dans le cas contraires on ne fait rien.
	 * 
	 * 	@method	callBehaviour
	 *	utilisation :	myError.callBehaviour()
	 *	sortie :	Void
	 */
	public function callBehaviour ()
	{
		if(behaviour) behaviour(message);
	}
}