﻿/**************************************************
			 import des classes delfiweb
***************************************************/
import com.delfiweb.error.*;



/*
@class com.delfiweb.utils.LoadStack
@version 0.1
@author Cédric Néhémie
description :  Pour charger une pile de fichiers d'un coup
*/
class com.delfiweb.utils.LoadStack
{
	
	
	/*
	propriété :  _movieClipLoader (MovieClipLoader) Le MovieClipLoader
	propriété :  _tabClips (Array) le tableau des clips a charger
	propriété :  _pourcActu (Number) le pourcentage courant
	propriété :  _clipCourant (Number) le clip courant
	*/
	private var _movieClipLoader:MovieClipLoader;
	private var _tabClips:Array;
	private var _clipCourant:Number;
	private var _pourcActu:Number;
	private var _isLoading:Boolean;
	private var _listeners:Array;
	
	
	
	// le constructeur
	public function LoadStack ()
	{
		_movieClipLoader = new MovieClipLoader ();
		_tabClips = new Array ();
		_pourcActu = _clipCourant = 0;
		_isLoading = false;
		_listeners = new Array();
	}
	
	
	
	/*
	entrée :  url (String) L'adresse du fichier
	entrée :  cible (MovieClip) le clip dans lequel charger le fichier
	utilisation :  myLoadStack.loadClip(url, clip);
	description :  ajoute un clip dans la pile si on est pas entrain d'en charger d'autres
	*/
	public function loadClip (url:String, cible:MovieClip):Void
	{
		if (!_isLoading)
		{
			_tabClips.push ({url:url, cible:cible});
		}
	}
	
	
	
	/*
	utilisation :  myLoadStack.startLoad();
	description :  Démarre le chargement de toute la pile de fichiers
	*/
	public function startLoad ()
	{
		if(!_isLoading)
		{			
			_isLoading = true;
			_movieClipLoader.addListener (this);			
			_movieClipLoader.loadClip (_tabClips[_clipCourant].url, _tabClips[_clipCourant].cible);		
			notifyListeners ("onLoadStart");
		}
	}
	
	
	
	// pour écouter la progression du chargement
	public function onLoadProgress (cible:MovieClip, inO:Number, totO:Number)
	{
		var part = 100/_tabClips.length;
		var pcur = (inO/totO);
		var p = _clipCourant*part + pcur*part;
		_pourcActu = Math.floor(p);
		notifyListeners ("onLoadProgress");
	}
	
	
	
	// écouter la notification d'un évènement à la fin du chargement
	public function onLoadComplete (cible:MovieClip)
	{
		_clipCourant++;
		if (_clipCourant == _tabClips.length)
		{
			_isLoading = false;
			_pourcActu = 100;
			notifyListeners ("onLoadProgress");
			notifyListeners ("onLoadComplete");
			_clipCourant = 0;
			_tabClips = new Array ();
		}
		else
		{
			_movieClipLoader.loadClip (_tabClips[_clipCourant].url, _tabClips[_clipCourant].cible);
			var part = 100/_tabClips.length;
			var p = Math.floor((_clipCourant)*part);
			_pourcActu = p;
			//notifyListeners ("onLoadProgress");
			//notifyListeners ("onLoadStep");
		}
	}
	
	
	
	// en cas d'erreur de chargement de fichiers
	public function onLoadError (cible,codeerreur)
	{
		_global.ajoutLog("(var) erreur chargement : "+codeerreur+" dans "+cible);
		//notifyListeners ("onLoadError",codeerreur);
		// le message - la fonction - la priorité de l'erreur
		var erreur = new DError("Erreur chargement : "+codeerreur+" dans "+cible,"LoadStack.onLoadError",DError.WARN)
		ErrorDispatcher.send(erreur);
	}
	
	
	public function get currentRate ():Number
	{
		return _pourcActu;
	}
	
	
	public function get stack():Array
	{
		return _tabClips;
	}
	
	
	/**
	* entrée :  obj (Object) L'objet écouteur
	* description :  Ajoute un écouteur à notre objet
	*/
	public function addListener (o:Object):Boolean
	{
		for(var i in _listeners)
		{
			if(_listeners[i] == o)
			{
				return false;
			}
		}
		_listeners.push(o);
		return true;
	}
	
	
	/**
	* entrée :  obj (Object) L'objet écouteur
	* description :  Enleve un écouteur à notre objet
	*/
	public function removeListener (o:Object):Boolean
	{
		for(var i in _listeners)
		{
			if(_listeners[i] == o)
			{
				_listeners.splice(Number(i),1);
				return true;
			}
		}
		return false;
	}
	
	
	/**
	* entrée :  event (String) Le nom de l'évènement
	* entrée :  obj (Object) L'objet évènement
	* description :  Notifie un évènement à tous les écouteurs
	*/
	public function notifyListeners (e:String, obj:Object):Void
	{
		for(var i in _listeners)
		{
			_listeners[i][e](obj);
		}
	}
	
	
}


